@@ -371,13 +371,6 @@ const DocCommon = new Lang.Class({
         log('Error: DocCommon implementations must override canTrash');
     },
 
-    canPrint: function(docModel) {
-        if (!docModel)
-            return false;
-
-        return EvView.PrintOperation.exists_for_document(docModel.get_document());
-    },
-
     trash: function() {
         if (!this.canTrash())
             return;
@@ -617,9 +610,6 @@ const DocCommon = new Lang.Class({
                     return;
                 }
 
-                if (!this.canPrint(docModel))
-                    return;
-
                 let printOp = EvView.PrintOperation.new(docModel.get_document());
 
                 printOp.connect('begin-print', Lang.bind(this,
@@ -678,25 +668,13 @@ const LocalDocument = new Lang.Class({
         this.sourceName = _("Local");
 
         if (this.mimeType) {
-            let defaultApp = Gio.app_info_get_default_for_type(this.mimeType, true);
-            let recommendedApp = null;
-
             let apps = Gio.app_info_get_recommended_for_type (this.mimeType);
             for (let i = 0; i < apps.length; i++) {
                 if (apps[i].supports_uris ()) {
-                    if (defaultApp && apps[i].equal (defaultApp)) {
-                        // Found the recommended app that's also the default
-                        recommendedApp = apps[i];
-                        break;
-                    }
-                    // Set the first recommendedApp as the default if
-                    // they don't match
-                    if (!recommendedApp)
-                        recommendedApp = apps[i];
+                    this.defaultApp = apps[i];
+                    break;
                 }
             }
-
-            this.defaultApp = recommendedApp;
         }
 
         if (this.defaultApp)
@@ -805,7 +783,7 @@ const GoogleDocument = new Lang.Class({
         this.sourceName = _("Google");
     },
 
-    createGDataEntry: function(cancellable, callback) {
+    _createGDataEntry: function(cancellable, callback) {
         let source = Application.sourceManager.getItemById(this.resourceUrn);
 
         let authorizer = new GData.GoaAuthorizer({ goa_object: source.object });
@@ -832,7 +810,7 @@ const GoogleDocument = new Lang.Class({
     },
 
     load: function(passwd, cancellable, callback) {
-        this.createGDataEntry(cancellable, Lang.bind(this,
+        this._createGDataEntry(cancellable, Lang.bind(this,
             function(entry, service, exception) {
                 if (exception) {
                     // try loading from the most recent cache, if any
@@ -864,7 +842,7 @@ const GoogleDocument = new Lang.Class({
     },
 
     createThumbnail: function(callback) {
-        this.createGDataEntry(null, Lang.bind(this,
+        this._createGDataEntry(null, Lang.bind(this,
             function(entry, service, exception) {
                 if (exception) {
                     callback(false);
