@@ -53,13 +53,22 @@ const MainToolbar = new Lang.Class({
         if (this.searchbar)
             this.widget.add(this.searchbar.widget);
 
-        Application.documentManager.connect('load-started', Lang.bind(this,
+        let loadStartedId = Application.documentManager.connect('load-started', Lang.bind(this,
             function() {
                 this._handleEvent = true;
             }));
 
-        Application.documentManager.connect('load-error', Lang.bind(this, this._onLoadErrorOrPassword));
-        Application.documentManager.connect('password-needed', Lang.bind(this, this._onLoadErrorOrPassword));
+        let loadErrorId = Application.documentManager.connect('load-error',
+            Lang.bind(this, this._onLoadErrorOrPassword));
+        let passwordNeededId = Application.documentManager.connect('password-needed',
+            Lang.bind(this, this._onLoadErrorOrPassword));
+
+        this.widget.connect('destroy', Lang.bind(this,
+            function() {
+                Application.documentManager.disconnect(loadStartedId);
+                Application.documentManager.disconnect(loadErrorId);
+                Application.documentManager.disconnect(passwordNeededId);
+            }));
     },
 
     _onLoadErrorOrPassword: function() {
@@ -116,18 +125,14 @@ const OverviewToolbar = new Lang.Class({
         this._stackSwitcher.show();
 
         // setup listeners to mode changes that affect the toolbar layout
-        this._selectionModeId = Application.selectionController.connect('selection-mode-changed',
+        let selectionModeId = Application.selectionController.connect('selection-mode-changed',
             Lang.bind(this, this._resetToolbarMode));
         this._resetToolbarMode();
 
         this.widget.connect('destroy', Lang.bind(this,
             function() {
                 this._clearStateData();
-
-                if (this._selectionModeId != 0) {
-                    Application.selectionController.disconnect(this._selectionModeId);
-                    this._selectionModeId = 0;
-                }
+                Application.selectionController.disconnect(selectionModeId);
             }));
     },
 
@@ -243,7 +248,6 @@ const OverviewToolbar = new Lang.Class({
     _onActiveCollectionChanged: function() {
         this._checkCollectionWidgets();
         this._setToolbarTitle();
-        Application.application.change_action_state('search', GLib.Variant.new('b', false));
     },
 
     _populateForOverview: function() {
