@@ -59,16 +59,25 @@ const PlacesDialog = new Lang.Class({
                                       homogeneous: true });
         contentArea.pack_start(this._stack, true, true, 0);
 
-        let header = this.widget.get_header_bar();
-        let switcher = new Gtk.StackSwitcher({ stack: this._stack });
-        header.set_custom_title(switcher);
+        let evDoc = this._model.get_document();
+        let docHasLinks = false;
 
-        this._linksPage = new GdPrivate.PlacesLinks();
-        this._linksPage.connect('link-activated', Lang.bind(this,
-            function(widget, link) {
-                this._handleLink(link);
-            }));
-        this._addPage(this._linksPage);
+        try {
+            // This is a hack to find out if evDoc implements the
+            // EvDocument.DocumentLinks interface or not.
+            docHasLinks = evDoc.has_document_links();
+        } catch (e if e instanceof TypeError) {
+        } catch (e) {
+        }
+
+        if (docHasLinks) {
+            this._linksPage = new GdPrivate.PlacesLinks();
+            this._linksPage.connect('link-activated', Lang.bind(this,
+                function(widget, link) {
+                    this._handleLink(link);
+                }));
+            this._addPage(this._linksPage);
+        }
 
         if (this._bookmarks) {
             this._bookmarksPage = new GdPrivate.PlacesBookmarks({ bookmarks: this._bookmarks });
@@ -78,6 +87,16 @@ const PlacesDialog = new Lang.Class({
                 }));
             this._addPage(this._bookmarksPage);
         }
+
+        let pages = this._stack.get_children();
+        let header = this.widget.get_header_bar();
+
+        if (pages.length == 1) {
+            header.set_title(pages[0].name);
+        } else if (pages.length > 1) {
+            let switcher = new Gtk.StackSwitcher({ stack: this._stack });
+            header.set_custom_title(switcher);
+        }
     },
 
     _handleLink: function(link) {
