@@ -136,8 +136,8 @@ const PreviewView = new Lang.Class({
             function() {
                 this._changeRotation(90);
             }));
-        this._places = Application.application.lookup_action('places');
-        let placesId = this._places.connect('activate', Lang.bind(this, this._showPlaces));
+        let showPlaces = Application.application.lookup_action('places');
+        let showPlacesId = showPlaces.connect('activate', Lang.bind(this, this._showPlaces));
 
         let nightModeId = Application.application.connect('action-state-changed::night-mode',
             Lang.bind(this, this._updateNightMode));
@@ -161,7 +161,7 @@ const PreviewView = new Lang.Class({
                 this._copy.disconnect(copyId);
                 rotLeft.disconnect(rotLeftId);
                 rotRight.disconnect(rotRightId);
-                this._places.disconnect(placesId);
+                showPlaces.disconnect(showPlacesId);
                 Application.application.disconnect(presentCurrentId);
                 Application.application.disconnect(nightModeId);
             }));
@@ -169,7 +169,7 @@ const PreviewView = new Lang.Class({
 
     _onLoadStarted: function() {
         this._bookmarkPage.enabled = false;
-        this._places.enabled = false;
+        this._showPlaces.enabled = false;
         this._copy.enabled = false;
     },
 
@@ -560,13 +560,11 @@ const PreviewView = new Lang.Class({
 
             let hasMultiplePages = (this._model.document.get_n_pages() > 1);
             this._bookmarkPage.enabled = hasMultiplePages && this._bookmarks;
-            this._places.enabled = hasMultiplePages;
+            this._showPlaces.enabled = hasMultiplePages;
 
             this._model.connect('page-changed', Lang.bind(this, this._onPageChanged));
 
             this._updateNightMode();
-
-            this.widget.set_visible_child_full('view', Gtk.StackTransitionType.NONE);
         }
     },
 
