@@ -23,7 +23,6 @@ const Cairo = imports.gi.cairo;
 const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
 const Gettext = imports.gettext;
-const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
@@ -361,7 +360,6 @@ const ViewContainer = new Lang.Class({
         let selectAll = Application.application.lookup_action('select-all');
         let selectAllId = selectAll.connect('activate', Lang.bind(this,
             function() {
-                Application.selectionController.setSelectionMode(true);
                 this.view.select_all();
             }));
 
